| Title: | Experience Research |
|---|---|
| Description: | Provides convenience functions for researching experiences including user, customer, patient, employee, and other human experiences. It provides a suite of tools to simplify data exploration such as benchmarking, comparing groups, and checking for differences. The outputs translate statistical approaches in applied experience research to human readable output. |
| Authors: | Joe Chelladurai [aut, cre]
|
| Maintainer: | Joe Chelladurai <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.1 |
| Built: | 2026-05-26 06:57:03 UTC |
| Source: | https://github.com/cran/experiences |
Compare Probability of an Event with Benchmark
compare_benchmark_event( benchmark, event, total, event_type = "", notes = c("minimal", "technical") )compare_benchmark_event( benchmark, event, total, event_type = "", notes = c("minimal", "technical") )
benchmark |
benchmark |
event |
event |
total |
total |
event_type |
Optional: a string describing the type of event. For example, success, failure, etc. |
notes |
whether output should contain minimal, technical, or executive type of notes. |
list of event rate, probability, notes
compare_benchmark_event(benchmark = 0.7, event = 10, total = 12, event_type = "success", notes = "minimal")compare_benchmark_event(benchmark = 0.7, event = 10, total = 12, event_type = "success", notes = "minimal")
Compare Score with a Benchmark
compare_benchmark_score( data, benchmark, alpha, tail = "one", remove_missing = TRUE )compare_benchmark_score( data, benchmark, alpha, tail = "one", remove_missing = TRUE )
data |
a column or vector of scores |
benchmark |
benchmark |
alpha |
alpha |
tail |
one-tailed or two-tailed test |
remove_missing |
TRUE/FALSE remove missing values? (default is TRUE) |
lower_ci, upper_ci, t, probability
data <- 68 + 17 * scale(rnorm(20)) # 68 = mean, 17 = sd compare_benchmark_score(data, benchmark = 60, alpha = 0.5)data <- 68 + 17 * scale(rnorm(20)) # 68 = mean, 17 = sd compare_benchmark_score(data, benchmark = 60, alpha = 0.5)
Compare Time with a Benchmark
compare_benchmark_time(benchmark, time, alpha, remove_missing = FALSE)compare_benchmark_time(benchmark, time, alpha, remove_missing = FALSE)
benchmark |
benchmark |
time |
a column or vector of time values |
alpha |
alpha |
remove_missing |
TRUE/FALSE remove missing values? |
lower_ci, upper_ci, t, probability
compare_benchmark_time(time = c(60, 53, 70, 42, 62, 43, 81), benchmark = 60, alpha = 0.05)compare_benchmark_time(time = c(60, 53, 70, 42, 62, 43, 81), benchmark = 60, alpha = 0.05)
T distribution - one-tailed
t_dist_one_tailed(t_score, degrees_of_freedom)t_dist_one_tailed(t_score, degrees_of_freedom)
t_score |
t value |
degrees_of_freedom |
degrees of freedom |
value
T distribution - two-tailed
t_dist_two_tailed(t_score, degrees_of_freedom)t_dist_two_tailed(t_score, degrees_of_freedom)
t_score |
t value |
degrees_of_freedom |
degrees of freedom |
value